@@ -10,7 +10,7 @@ static PerlInterpreter *my_perl;
 ** Returns the number of successful matches, and
 ** modifies the input string if there were any.
 **/
-void xs_init(void);
+
 static int regex(char *string[], char *operation)
 {
   int n;
@@ -49,7 +49,7 @@ main (int argc, char **argv, char **env)
   text = argv[1];
   my_perl = perl_alloc();
   perl_construct( my_perl );
-  perl_parse(my_perl, xs_init, 2, embedding, NULL);
+  perl_parse(my_perl, NULL, 2, embedding, NULL);
   perl_run(my_perl);
   
   if(num_matches = regex(&text, "m/([a-z]{4,6})/gi")) {
